==> jc-1.4.0.tar.gz: ppg/spec/Spec.h <==
// public abstract class ppg.spec.Spec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1951087704cee416 ppg_spec_Spec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_spec_Spec_H_
#define _JC_ppg_spec_Spec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Vector$object;
struct _jc_ppg_code_ActionCode$object;
struct _jc_ppg_code_InitCode$object;
struct _jc_ppg_code_ParserCode$object;
struct _jc_ppg_code_ScanCode$object;
struct _jc_ppg_spec_CUPSpec$object;
struct _jc_ppg_spec_PPGSpec$object;

// Typedefs
typedef struct _jc_ppg_spec_Spec$sub_refs	_jc_ppg_spec_Spec$sub_refs;
typedef struct _jc_ppg_spec_Spec$sub_nonrefs	_jc_ppg_spec_Spec$sub_nonrefs;
typedef struct _jc_ppg_spec_Spec$refs	_jc_ppg_spec_Spec$refs;
typedef struct _jc_ppg_spec_Spec$nonrefs	_jc_ppg_spec_Spec$nonrefs;
typedef struct _jc_ppg_spec_Spec$object	_jc_ppg_spec_Spec$object;

typedef const struct _jc_ppg_spec_Spec$vmethods	_jc_ppg_spec_Spec$vmethods;
typedef const struct _jc_ppg_spec_Spec$vtable	_jc_ppg_spec_Spec$vtable;
typedef const struct _jc_ppg_spec_Spec$vtype	_jc_ppg_spec_Spec$vtype;

// Constructors
extern void _jc_ppg_spec_Spec$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_spec_Spec$object *);

// Virtual methods
extern void _jc_ppg_spec_Spec$method$addImports$8fb74fa3e28d0f22(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_util_Vector$object *);
extern struct _jc_ppg_spec_CUPSpec$object *_jc_ppg_spec_Spec$method$coalesce$6ce1483990d30401(_jc_env *, struct _jc_ppg_spec_Spec$object *);
extern void _jc_ppg_spec_Spec$method$parseChain$236e2fd64a3392a3(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_lang_String$object *);
extern void _jc_ppg_spec_Spec$method$replaceCode$becbfb7c0a10eaf8(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_util_Vector$object *);
extern void _jc_ppg_spec_Spec$method$setChild$040f7d042d27206e(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_ppg_spec_PPGSpec$object *);
extern void _jc_ppg_spec_Spec$method$setPkgName$857957b5ad532227(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_spec_Spec$method_info$addImports$8fb74fa3e28d0f22;
extern _jc_method _jc_ppg_spec_Spec$method_info$coalesce$6ce1483990d30401;
extern _jc_method _jc_ppg_spec_Spec$method_info$parseChain$236e2fd64a3392a3;
extern _jc_method _jc_ppg_spec_Spec$method_info$replaceCode$becbfb7c0a10eaf8;
extern _jc_method _jc_ppg_spec_Spec$method_info$setChild$040f7d042d27206e;
extern _jc_method _jc_ppg_spec_Spec$method_info$setPkgName$857957b5ad532227;

// Virtual methods structure
struct _jc_ppg_spec_Spec$vmethods {
	void	(*addImports$8fb74fa3e28d0f22)(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_util_Vector$object *);
	struct _jc_ppg_spec_CUPSpec$object	*(*coalesce$6ce1483990d30401)(_jc_env *, struct _jc_ppg_spec_Spec$object *);
	void	(*parseChain$236e2fd64a3392a3)(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_lang_String$object *);
	void	(*replaceCode$becbfb7c0a10eaf8)(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_util_Vector$object *);
	void	(*setChild$040f7d042d27206e)(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_ppg_spec_PPGSpec$object *);
	void	(*setPkgName$857957b5ad532227)(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_ppg_spec_Spec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_spec_Spec$vmethods	ppg_spec_Spec;
};

// Vtype
struct _jc_ppg_spec_Spec$vtype {
	_jc_type			type;
	_jc_ppg_spec_Spec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_spec_Spec$sub_refs {
	struct _jc_java_lang_String$object	*packageName;
	struct _jc_java_util_Vector$object	*imports;
	struct _jc_java_util_Vector$object	*symbols;
	struct _jc_java_util_Vector$object	*prec;
	struct _jc_ppg_code_InitCode$object	*initCode;
	struct _jc_ppg_code_ActionCode$object	*actionCode;
	struct _jc_ppg_code_ParserCode$object	*parserCode;
	struct _jc_ppg_code_ScanCode$object	*scanCode;
	struct _jc_ppg_spec_PPGSpec$object	*child;
};

// Reference instance fields (object)
struct _jc_ppg_spec_Spec$refs {
    _jc_ppg_spec_Spec$sub_refs	ppg_spec_Spec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_spec_Spec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_spec_Spec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_spec_Spec$sub_nonrefs	ppg_spec_Spec;
};

// Object instance structure
struct _jc_ppg_spec_Spec$object {
	_jc_ppg_spec_Spec$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_spec_Spec$vtype	*vtype;
	_jc_ppg_spec_Spec$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_spec_Spec$vtype _jc_ppg_spec_Spec$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_spec_Spec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_spec_Spec$class_object;

#endif	/* _JC_ppg_spec_Spec_H_ */

==> jc-1.4.6.tar.gz: ppg/spec/Spec.h <==
// public abstract class ppg.spec.Spec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1951087704cee416 ppg_spec_Spec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_spec_Spec_H_
#define _JC_ppg_spec_Spec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Vector$object;
struct _jc_ppg_code_ActionCode$object;
struct _jc_ppg_code_InitCode$object;
struct _jc_ppg_code_ParserCode$object;
struct _jc_ppg_code_ScanCode$object;
struct _jc_ppg_spec_CUPSpec$object;
struct _jc_ppg_spec_PPGSpec$object;

// Typedefs
typedef struct _jc_ppg_spec_Spec$sub_refs	_jc_ppg_spec_Spec$sub_refs;
typedef struct _jc_ppg_spec_Spec$sub_nonrefs	_jc_ppg_spec_Spec$sub_nonrefs;
typedef struct _jc_ppg_spec_Spec$refs	_jc_ppg_spec_Spec$refs;
typedef struct _jc_ppg_spec_Spec$nonrefs	_jc_ppg_spec_Spec$nonrefs;
typedef struct _jc_ppg_spec_Spec$object	_jc_ppg_spec_Spec$object;

typedef const struct _jc_ppg_spec_Spec$vmethods	_jc_ppg_spec_Spec$vmethods;
typedef const struct _jc_ppg_spec_Spec$vtable	_jc_ppg_spec_Spec$vtable;
typedef const struct _jc_ppg_spec_Spec$vtype	_jc_ppg_spec_Spec$vtype;

// Constructors
extern void _jc_ppg_spec_Spec$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_spec_Spec$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_ppg_spec_Spec$method$addImports$8fb74fa3e28d0f22(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_util_Vector$object *) _JC_JCNI_ATTR;
extern struct _jc_ppg_spec_CUPSpec$object *_jc_ppg_spec_Spec$method$coalesce$6ce1483990d30401(_jc_env *, struct _jc_ppg_spec_Spec$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_spec_Spec$method$parseChain$236e2fd64a3392a3(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_spec_Spec$method$replaceCode$becbfb7c0a10eaf8(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_util_Vector$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_spec_Spec$method$setChild$040f7d042d27206e(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_ppg_spec_PPGSpec$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_spec_Spec$method$setPkgName$857957b5ad532227(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_spec_Spec$method_info$addImports$8fb74fa3e28d0f22;
extern _jc_method _jc_ppg_spec_Spec$method_info$coalesce$6ce1483990d30401;
extern _jc_method _jc_ppg_spec_Spec$method_info$parseChain$236e2fd64a3392a3;
extern _jc_method _jc_ppg_spec_Spec$method_info$replaceCode$becbfb7c0a10eaf8;
extern _jc_method _jc_ppg_spec_Spec$method_info$setChild$040f7d042d27206e;
extern _jc_method _jc_ppg_spec_Spec$method_info$setPkgName$857957b5ad532227;

// Virtual methods structure
struct _jc_ppg_spec_Spec$vmethods {
	void	(*addImports$8fb74fa3e28d0f22)(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_util_Vector$object *) _JC_JCNI_ATTR;
	struct _jc_ppg_spec_CUPSpec$object	*(*coalesce$6ce1483990d30401)(_jc_env *, struct _jc_ppg_spec_Spec$object *) _JC_JCNI_ATTR;
	void	(*parseChain$236e2fd64a3392a3)(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*replaceCode$becbfb7c0a10eaf8)(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_util_Vector$object *) _JC_JCNI_ATTR;
	void	(*setChild$040f7d042d27206e)(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_ppg_spec_PPGSpec$object *) _JC_JCNI_ATTR;
	void	(*setPkgName$857957b5ad532227)(_jc_env *, struct _jc_ppg_spec_Spec$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_spec_Spec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_spec_Spec$vmethods	ppg_spec_Spec;
};

// Vtype
struct _jc_ppg_spec_Spec$vtype {
	_jc_type			type;
	_jc_ppg_spec_Spec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_spec_Spec$sub_refs {
	struct _jc_java_lang_String$object	*packageName;
	struct _jc_java_util_Vector$object	*imports;
	struct _jc_java_util_Vector$object	*symbols;
	struct _jc_java_util_Vector$object	*prec;
	struct _jc_ppg_code_InitCode$object	*initCode;
	struct _jc_ppg_code_ActionCode$object	*actionCode;
	struct _jc_ppg_code_ParserCode$object	*parserCode;
	struct _jc_ppg_code_ScanCode$object	*scanCode;
	struct _jc_ppg_spec_PPGSpec$object	*child;
};

// Reference instance fields (object)
struct _jc_ppg_spec_Spec$refs {
    _jc_ppg_spec_Spec$sub_refs	ppg_spec_Spec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_spec_Spec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_spec_Spec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_spec_Spec$sub_nonrefs	ppg_spec_Spec;
};

// Object instance structure
struct _jc_ppg_spec_Spec$object {
	_jc_ppg_spec_Spec$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_spec_Spec$vtype	*vtype;
	_jc_ppg_spec_Spec$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_spec_Spec$vtype _jc_ppg_spec_Spec$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_spec_Spec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_spec_Spec$class_object;

#endif	/* _JC_ppg_spec_Spec_H_ */
